pub struct FileFilter { /* private fields */ }Implementations
Sourceimpl FileFilter
impl FileFilter
Sourcepub fn new(use_defaults: bool, custom_patterns: &[String]) -> Result<Self>
pub fn new(use_defaults: bool, custom_patterns: &[String]) -> Result<Self>
create new file filter with optional custom patterns
Sourcepub fn should_exclude(&self, path: &Path) -> bool
pub fn should_exclude(&self, path: &Path) -> bool
check if a path should be excluded from archiving
Sourcepub fn should_exclude_relative(&self, relative_path: &Path) -> bool
pub fn should_exclude_relative(&self, relative_path: &Path) -> bool
check if a relative path should be excluded from archiving
Sourcepub fn should_exclude_path(&self, root: &Path, path: &Path) -> bool
pub fn should_exclude_path(&self, root: &Path, path: &Path) -> bool
check if a path should be excluded, based on its relative path to a root
Sourcepub fn should_include(&self, path: &Path) -> bool
pub fn should_include(&self, path: &Path) -> bool
check if a path should be included in archiving (inverse of should_exclude)
Sourcepub fn should_include_relative(&self, relative_path: &Path) -> bool
pub fn should_include_relative(&self, relative_path: &Path) -> bool
check if a relative path should be included in archiving
Sourcepub fn should_include_path(&self, root: &Path, path: &Path) -> bool
pub fn should_include_path(&self, root: &Path, path: &Path) -> bool
check if a path should be included, based on its relative path to a root